package com.ynxbd.push.helper;

import org.apache.http.client.config.RequestConfig;
import org.apache.http.impl.nio.client.CloseableHttpAsyncClient;
import org.apache.http.impl.nio.client.HttpAsyncClients;
import org.apache.http.impl.nio.conn.PoolingNHttpClientConnectionManager;
import org.apache.http.impl.nio.reactor.DefaultConnectingIOReactor;
import org.apache.http.impl.nio.reactor.IOReactorConfig;
import org.apache.http.nio.reactor.ConnectingIOReactor;
import org.apache.http.nio.reactor.IOReactorException;

/**
 * http异步线程池
 *
 * @author 李进才
 */
public class HttpAsyncClientHelper {
    private HttpAsyncClientHelper(){}
    public static CloseableHttpAsyncClient getHttpAsyncClient() {
        RequestConfig requestConfig = RequestConfig.custom()
                // 连接对象服务器超时时间（发起）
                .setConnectTimeout(50000)
                //跟对象服务器交互超时时间（握手）
                .setSocketTimeout(50000)
                // 从连接池获取连接超时时间
                .setConnectionRequestTimeout(50000)
                .build();
        //配置io线程
        IOReactorConfig ioReactorConfig = IOReactorConfig.custom().
                setIoThreadCount(15)
                .setSoKeepAlive(true)
                .build();
        //设置连接池大小
        ConnectingIOReactor ioReactor = null;
        try {
            ioReactor = new DefaultConnectingIOReactor(ioReactorConfig);
        } catch (IOReactorException e) {
            e.printStackTrace();
        }
        PoolingNHttpClientConnectionManager connManager = new PoolingNHttpClientConnectionManager(ioReactor);
        connManager.setMaxTotal(2000);
        connManager.setDefaultMaxPerRoute(2000);
        return HttpAsyncClients.custom().
                setConnectionManager(connManager)
                .setDefaultRequestConfig(requestConfig)
                .build();
    }
}
