package com.ynxbd.push.helper;

import com.alibaba.fastjson.JSONObject;
import org.springframework.util.ObjectUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * map转换工具类
 */
public class MapHelper {

    /**
     * obj类型map转str类型map
     *
     * @param objMap obj类型map
     * @return str类型map
     */
    public static Map<String, String> objMapToStrMap(Map<String, Object> objMap) {
        Map<String, String> strMap = new HashMap<>();
        for (Map.Entry<String, Object> item : objMap.entrySet()) {
            String key = item.getKey();
            if (ObjectUtils.isEmpty(key)) {
                continue;
            }
            Object value = item.getValue();
            if (ObjectUtils.isEmpty(value)) {
                strMap.put(key, null);
                continue;
            }
            if (value instanceof Map) {
                strMap.put(key, JSONObject.toJSONString(value));
            } else {
                strMap.put(key, value.toString());
            }
        }
        return strMap;
    }


    /**
     * str类型map转obj类型map
     *
     * @param strMap str类型map
     * @return obj类型map
     */
    public static Map<String, Object> strMapToObjMap(Map<String, String> strMap) {
        Map<String, Object> objMap = new HashMap<>();
        for (Map.Entry<String, String> item : strMap.entrySet()) {
            String key = item.getKey();
            if (key == null) {
                continue;
            }
            String value = item.getValue();
            if (value == null) {
                objMap.put(key, "");
            } else {
                objMap.put(key, getJsonVal(value));
            }
        }
        return objMap;
    }

    /**
     * 获取Json值
     *
     * @param value 值
     * @return Object
     */
    public static Object getJsonVal(String value) {
        if (ObjectUtils.isEmpty(value)) {
            return "";
        }
        try {
            return JSONObject.parse(value);
        } catch (Exception e) {
            return "";
        }
    }
}
