package com.ynxbd.push.quartz.listener;

import com.ynxbd.push.quartz.scheduler.AppQuartzScheduler;
import lombok.extern.slf4j.Slf4j;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.SchedulerFactory;
import org.quartz.impl.StdSchedulerFactory;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.ContextRefreshedEvent;

import javax.annotation.Resource;

/**
 * 任务监听器
 * @author 李进才
 */

@Slf4j
@Configuration
public class AppStartQuartzJobListener implements ApplicationListener<ContextRefreshedEvent> {
    @Resource
    private AppQuartzScheduler quartzScheduler;

    /**
     * 初始启动quartz
     */
    @Override
    public void onApplicationEvent(ContextRefreshedEvent event) {
        try {
            log.info("[<QUZRTZ DISPATCH>]Starting Quartz task ...");
            quartzScheduler.startCrontabJob();
            quartzScheduler.startWorkloadJob();
            quartzScheduler.startTodayRegJob();
        } catch (SchedulerException e) {
            log.error("[<QUZRTZ DISPATCH>]ERROR: ", e);
        }
    }

    /**
     * 初始注入scheduler
     */
    @Bean
    public Scheduler scheduler() throws SchedulerException {
        SchedulerFactory schedulerFactoryBean = new StdSchedulerFactory();
        return schedulerFactoryBean.getScheduler();
    }

}
