package com.ynxbd.push.quartz.pushJob.TodayReg;

import com.alibaba.fastjson.JSONObject;
import com.ynxbd.push.config.IniConfig;
import com.ynxbd.push.entity.enums.MsgParamEnum;
import com.ynxbd.push.entity.tencent.SendTemplate;
import com.ynxbd.push.entity.type.MessageTypeEnum;
import com.ynxbd.push.entity.xbd.wx.Register;
import com.ynxbd.push.helper.MessageApiHelper;
import com.ynxbd.push.httpRequest.tencent.WeChatDataRequest;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.time.LocalTime;

/**
 * @author 李进才
 * @ClassName TodayReg
 * @Description TODO
 * @date 2024/05/23 10:04:00
 */
@Slf4j
public class TodayReg {
      public static void runJon(){
          String templateId = WeChatDataRequest.getTemplateId("候诊提醒");
          if(templateId==null)
          {
              log.info("[今日预约患者推送]微信公众平台未设置推送模版,定时任务执行结束");
              return;
          }
          String startTime;
          String endTime;
          if(getCurrentTimePart()){
              startTime = "07:30";
              endTime = "12:00";
          }else {
              startTime = "12:00";
              endTime = "24:00:00";
          }
          WeChatDataRequest.todayRegSmS(startTime, endTime); //调用短信推送
          List<Register> registerList = WeChatDataRequest.getTodayRegRecord(startTime, endTime);
          for (Register register : registerList) {
              Map<String, Object> tempData = new HashMap<>();
              String messageId = UUID.randomUUID().toString();
              Map<String, String> paramsMap = getStringStringMap(register);
              log.info("[今日预约患者推送] message_id:{}, 推送数据:{}", messageId, JSONObject.toJSONString(paramsMap));

              try {
                  // 就诊人
                  MsgParamEnum.THING.put(paramsMap, tempData, "name", 1);
                  // 就诊科室
                  MsgParamEnum.THING.put(paramsMap, tempData, "deptName", 2);
                  // 就诊时间
                  MsgParamEnum.TIME.put(paramsMap, tempData, "begTime", 6);
                  // 候诊地点
                  MsgParamEnum.THING.put(paramsMap, tempData, "address", 7);
                  // 医生姓名
                  MsgParamEnum.THING.put(paramsMap, tempData, "doctorName", 12);
              }
              catch(Exception e) {
                  log.error("[今日预约患者推送] message_id:{},  拼装数据：{},数据拼装出错：{}", messageId, JSONObject.toJSONString(paramsMap),e.toString());
              }
              if(tempData.isEmpty()){
                  log.error("[今日预约患者推送] message_id:{},  数据拼装出错, 拼装数据：{}", messageId, JSONObject.toJSONString(paramsMap));
                  return;
              }
              SendTemplate sendTemplate = SendTemplate.builder()
                      .template_id(templateId)
                      .message_id(messageId)
                      .touser(register.getOpenid())
                      .code(MessageTypeEnum.COMMON.CODE)
                      .url(null)
                      .data(tempData)
                      .build();
              log.info("[今日预约患者推送] message_id:{},  开始推送-组合数据[{}]", messageId, JSONObject.toJSONString(sendTemplate));
              log.info("[今日预约患者推送] message_id:{},  推送结果:{}", messageId, JSONObject.toJSONString(MessageApiHelper.templateMessageSend(JSONObject.toJSONString(sendTemplate))));
          }
      }

    private static Map<String, String> getStringStringMap(Register register) {
        Map<String,String> paramsMap = new HashMap<>();
        paramsMap.put("deptName", register.getDeptName().trim().length()>16? register.getDeptName().trim().substring(0,16) + "..." : register.getDeptName().trim());
        paramsMap.put("begTime", register.getBegTime());
        paramsMap.put("address", register.getAddress().trim().length()>16? register.getAddress().trim().substring(0,16) + "..." : register.getAddress().trim());
        paramsMap.put("doctorName", register.getDoctName());
        paramsMap.put("name", register.getName());
        return paramsMap;
    }

    /**
     * 判断当前时间是上午还是下午
     * @return 返回1是上午，返回2是下午
     */
    private static Boolean getCurrentTimePart() {
        LocalTime now = LocalTime.now();
        return now.isBefore(LocalTime.NOON);
    }

}
